@@ -163,6 +163,12 @@ class KatRes:
       while self.reload():
         time.sleep(0.5)
 
+  def patch_with_flat_dict(self, flat_patches: Dict) -> Optional[KR]:
+    def modify(raw):
+      for deep_key, value in flat_patches.items():
+        utils.deep_setattr(raw, deep_key, value)
+    return self.patch(modify)
+
   def patch(self, modifier=None) -> Optional[KR]:
     if modifier is not None:
       self._enter_patch_loop(modifier)
